@@ -1,21 +1,14 @@
 #!/usr/bin/env python3
-try:
-    from selenium.webdriver.support.ui import WebDriverWait
-    from selenium.webdriver.support import expected_conditions as EC
-    from selenium.webdriver.common.by import By
-    from selenium.common.exceptions import WebDriverException
-    import time
-    from selenium.webdriver.common.by import By
-    from selenium.webdriver.support.ui import WebDriverWait
-    from selenium.webdriver.support import expected_conditions as EC
-    from selenium.webdriver.common.keys import Keys
-    from inspect import currentframe
-    from random import randint
-except Exception as ex:
-    frameinfo = currentframe()
-    print("Error on line no. {} : {}".format(frameinfo.f_lineno, ex))
+from selenium.webdriver.support.ui import WebDriverWait
+from selenium.webdriver.support import expected_conditions as EC
+from selenium.webdriver.common.by import By
+from selenium.common.exceptions import WebDriverException
+import time
+from selenium.webdriver.common.keys import Keys
+from random import randint
+import logging
 
-frameinfo = currentframe()
+logging.getLogger().setLevel(logging.INFO)
 
 
 class Utilities:
@@ -29,17 +22,17 @@ class Utilities:
             WebDriverWait(driver, 10).until(EC.presence_of_element_located(
                 (By.CSS_SELECTOR, '[data-testid="tweet"]')))
         except WebDriverException:
-            print(
+            logging.exception(
                 "Tweets did not appear!, Try setting headless=False to see what is happening")
 
     @staticmethod
     def __scroll_down(driver):
         try:
             body = driver.find_element(By.CSS_SELECTOR, 'body')
-            for _ in range(randint(1,3)):
+            for _ in range(randint(1, 3)):
                 body.send_keys(Keys.PAGE_DOWN)
         except Exception as ex:
-            print("Error on line no. {} : {}".format(frameinfo.f_lineno, ex))
+            logging.exception("Error at scroll_down method {}".format(ex))
 
     @staticmethod
     def __wait_until_completion(driver):
@@ -50,4 +43,4 @@ class Utilities:
                 time.sleep(randint(3, 5))
                 state = driver.execute_script("return document.readyState")
         except Exception as ex:
-            print(ex)
+            logging.exception('Error at wait_until_completion: {}'.format(ex))
