@@ -1,17 +1,12 @@
 #!/usr/bin/env python3
-try:
-    from selenium.common.exceptions import NoSuchElementException
-    from .scraping_utilities import Scraping_utilities
-    from inspect import currentframe
-    from dateutil.parser import parse
-    from selenium.webdriver.common.by import By
-except Exception as ex:
-    frameinfo = currentframe()
-    print("Error on line no. {} : {}".format(frameinfo.f_lineno, ex))
-
-frameinfo = currentframe()
 
+from selenium.common.exceptions import NoSuchElementException
+from .scraping_utilities import Scraping_utilities
+from dateutil.parser import parse
+from selenium.webdriver.common.by import By
+import logging
 
+logging.getLogger().setLevel(logging.INFO)
 class Finder:
     """
     this class should contain all  the static method to find that accept
@@ -27,9 +22,8 @@ class Finder:
     def __fetch_all_tweets(driver):
         try:
             return driver.find_elements(By.CSS_SELECTOR, '[data-testid="tweet"]')
-        except:
-            print("Error at method fetch_all_tweets on line no. {} : {}".format(
-                frameinfo.f_lineno, ex))
+        except Exception as ex:
+            logging.exception("Error at method fetch_all_tweets : {}".format(ex))
             return []
 
     @staticmethod
@@ -40,8 +34,7 @@ class Finder:
             replies = replies_element.get_attribute("aria-label")
             return Scraping_utilities._Scraping_utilities__extract_digits(replies)
         except Exception as ex:
-            print("Error at method find_replies on line no. {} : {}".format(
-                frameinfo.f_lineno, ex))
+            logging.exception("Error at method find_replies : {}".format(ex))
             return ""
 
     @staticmethod
@@ -52,8 +45,7 @@ class Finder:
             shares = shares_element.get_attribute("aria-label")
             return Scraping_utilities._Scraping_utilities__extract_digits(shares)
         except Exception as ex:
-            print("Error at method find_shares on line no. {} : {}".format(
-                frameinfo.f_lineno, ex))
+            logging.exception("Error at method find_shares : {}".format(ex))
             return ""
 
     @staticmethod
@@ -63,8 +55,7 @@ class Finder:
                 By.CSS_SELECTOR, "a.r-bcqeeo.r-3s2u2q.r-qvutc0")
             return (anchor.get_attribute("href").split("/"), anchor.get_attribute("href"))
         except Exception as ex:
-            print("Error at method find_status on line no. {} : {}".format(
-                frameinfo.f_lineno, ex))
+            logging.exception("Error at method find_status : {}".format(ex))
             return []
 
     @staticmethod
@@ -72,8 +63,7 @@ class Finder:
         try:
             return tweet.find_elements(By.TAG_NAME, 'a')
         except Exception as ex:
-            print("Error at method find_all_anchor_tags on line no. {} : {}".format(
-                frameinfo.f_lineno, ex))
+            logging.exception("Error at method find_all_anchor_tags : {}".format(ex))
 
     @staticmethod
     def __find_timestamp(tweet):
@@ -83,8 +73,7 @@ class Finder:
             posted_time = parse(timestamp).isoformat()
             return posted_time
         except Exception as ex:
-            print("Error at method find_timestamp on line no. {} : {}".format(
-                frameinfo.f_lineno, ex))
+            logging.exception("Error at method find_timestamp : {}".format(ex))
 
     @staticmethod
     def __find_content(tweet):
@@ -95,8 +84,7 @@ class Finder:
         except NoSuchElementException:
             return ""
         except Exception as ex:
-            print("Error at method find_content on line no. {} : {}".format(
-                frameinfo.f_lineno, ex))
+            logging.exception("Error at method find_content : {}".format(ex))
 
     @staticmethod
     def __find_like(tweet):
@@ -106,8 +94,7 @@ class Finder:
             likes = like_element.get_attribute("aria-label")
             return Scraping_utilities._Scraping_utilities__extract_digits(likes)
         except Exception as ex:
-            print("Error at method find_like on line no. {} : {}".format(
-                frameinfo.f_lineno, ex))
+            logging.exception("Error at method find_like : {}".format(ex))
 
     @staticmethod
     def __find_images(tweet):
@@ -121,8 +108,7 @@ class Finder:
                 images.append(href)
             return images
         except Exception as ex:
-            print("Error at method __find_images on line no. {} : {}".format(
-                frameinfo.f_lineno, ex))
+            logging.exception("Error at method find_images : {}".format(ex))
 
     @staticmethod
     def __find_videos(tweet):
@@ -136,8 +122,7 @@ class Finder:
                 videos.append(href)
             return videos
         except Exception as ex:
-            print("Error at method find_videos on line no. {} : {}".format(
-                frameinfo.f_lineno, ex))
+            logging.exception("Error at method find_videos : {}".format(ex))
 
     @staticmethod
     def __is_retweet(tweet):
@@ -147,8 +132,7 @@ class Finder:
         except NoSuchElementException:
             return False
         except Exception as ex:
-            print("Error at method is_retweet on line no. {} : {}".format(
-                frameinfo.f_lineno, ex))
+            logging.exception("Error at method is_retweet : {}".format(ex))
             return False
 
     @staticmethod
@@ -163,8 +147,7 @@ class Finder:
                     name = anchors[1].text.split("\n")[0]
             return name
         except Exception as ex:
-            print("Error at method __find_name_from_post on line no. {} : {}".format(
-                frameinfo.f_lineno, ex))
+            logging.exception("Error at method find_name_from_post : {}".format(ex))
 
     @staticmethod
     def __find_external_link(tweet):
@@ -177,5 +160,4 @@ class Finder:
         except NoSuchElementException:
             return ""
         except Exception as ex:
-            print("Error at method __find_external_link on line no. {} : {}".format(
-                frameinfo.f_lineno, ex))
+            logging.exception("Error at method find_external_link : {}".format(ex))
