@@ -1,26 +1,23 @@
 #!/usr/bin/env python3
-try:
-    from datetime import datetime, timedelta
-    from .driver_initialization import Initializer
-    from .driver_utils import Utilities
-    from inspect import currentframe
-    from .element_finder import Finder
-    import re
-    import json
-    import os
-    import csv
-    from twitter_scraper_selenium.scraping_utilities import Scraping_utilities
-except Exception as ex:
-    print(ex)
 
-frameinfo = currentframe()
+from .driver_initialization import Initializer
+from .driver_utils import Utilities
+from .element_finder import Finder
+import re
+import json
+import os
+import csv
+from twitter_scraper_selenium.scraping_utilities import Scraping_utilities
+import logging
+
+logging.getLogger().setLevel(logging.INFO)
 
 
 class Keyword:
     """this class needs to be instantiated in order to find something
     on twitter related to keywords"""
 
-    def __init__(self, keyword, browser, proxy, tweets_count, url, headless):
+    def __init__(self, keyword, browser, proxy, tweets_count, url, headless, browser_profile):
         self.keyword = keyword
         self.URL = url
         self.driver = ""
@@ -30,11 +27,12 @@ class Keyword:
         self.posts_data = {}
         self.retry = 10
         self.headless = headless
+        self.browser_profile = browser_profile
 
     def __start_driver(self):
         """changes the class member __driver value to driver on call"""
         self.__driver = Initializer(
-            self.browser, self.headless, self.proxy).init()
+            self.browser, self.headless, self.proxy, self.browser_profile).init()
 
     def __close_driver(self):
         self.__driver.close()
@@ -106,8 +104,8 @@ class Keyword:
                     break
 
         except Exception as ex:
-            print("Error at method scrap on line no. {} : {}".format(
-                frameinfo.f_lineno, ex))
+            logging.exception(
+                "Error at method fetch_and_store_data : {}".format(ex))
 
     def scrap(self):
         try:
@@ -120,12 +118,12 @@ class Keyword:
             self.__close_driver()
             data = dict(list(self.posts_data.items())
                         [0:int(self.tweets_count)])
-            return json.dumps(data)
+            return data
 
         except Exception as ex:
             self.__close_driver()
-            print(ex)
-            #print("Error at method scrap on line no. {} : {}".format(frameinfo.f_lineno,ex))
+            logging.exception(
+                "Error at method scrap on : {}".format(ex))
 
 
 def json_to_csv(filename, json_data, directory):
@@ -134,11 +132,15 @@ def json_to_csv(filename, json_data, directory):
     fieldnames = ['tweet_id', 'username', 'name', 'profile_picture', 'replies',
                   'retweets', 'likes', 'is_retweet', 'posted_time', 'content', 'hashtags', 'mentions',
                   'images', 'videos', 'tweet_url', 'link']
+    mode = 'w'
     # open and start writing to CSV files
-    with open("{}.csv".format(filename), 'w', newline='', encoding="utf-8") as data_file:
+    if os.path.exists("{}.csv".format(filename)):
+        mode = 'a'
+    with open("{}.csv".format(filename), mode, newline='', encoding="utf-8") as data_file:
         # instantiate DictWriter for writing CSV fi
         writer = csv.DictWriter(data_file, fieldnames=fieldnames)
-        writer.writeheader()  # write headers to CSV file
+        if mode == 'w':
+            writer.writeheader()  # write headers to CSV file
         # iterate over entire dictionary, write each posts as a row to CSV file
         for key in json_data:
             # parse post in a dictionary and write it as a single row
@@ -163,12 +165,13 @@ def json_to_csv(filename, json_data, directory):
             }
             writer.writerow(row)  # write row to CSV fi
         data_file.close()  # after writing close the file
+    logging.info('Data Successfully Saved to {}.csv'.format(filename))
 
 
 def scrap_keyword(keyword, browser="firefox", until=None,
                   since=None, since_id=None, max_id=None, within_time=None,
                   proxy=None, tweets_count=10, output_format="json",
-                  filename="", directory=os.getcwd(), headless=True):
+                  filename="", directory=os.getcwd(), headless=True, browser_profile=None):
     """
     Returns tweets data in CSV or JSON.
 
@@ -196,14 +199,38 @@ def scrap_keyword(keyword, browser="firefox", until=None,
     max_id(integer): At or before (inclusive) a specified Snowflake ID.
 
     within_time(string): Search within the last number of days, hours, minutes, or seconds.
+
+    browser_profile(string): Path of Browser Profile where cookies might be located to scrap data in authenticated way.
     """
     URL = Scraping_utilities._Scraping_utilities__url_generator(keyword, since=since, until=until,
                                                                 since_id=since_id, max_id=max_id, within_time=within_time)
     keyword_bot = Keyword(keyword, browser=browser, url=URL,
-                          proxy=proxy, tweets_count=tweets_count, headless=headless)
+                          proxy=proxy, tweets_count=tweets_count, headless=headless, browser_profile=browser_profile)
     data = keyword_bot.scrap()
-    if output_format == "json":
-        return data
+    if output_format.lower() == "json":
+        if filename == '':
+          # if filename was not provided then print the JSON to console
+            return json.dumps(data)
+        elif filename != '':
+          # if filename was provided, save it to that file
+            mode = 'w'
+            json_file_location = os.path.join(directory, filename+".json")
+            if os.path.exists(json_file_location):
+                mode = 'r'
+            with open(json_file_location, mode, encoding='utf-8') as file:
+                if mode == 'r':
+                    try:
+                        file_content = file.read()
+                        content = json.loads(file_content)
+                    except json.decoder.JSONDecodeError:
+                        logging.warning('Invalid JSON Detected!')
+                        content = {}
+                    file.close()
+                    data.update(content)
+                    with open(json_file_location, 'w', encoding='utf-8') as file_in_write_mode:
+                        json.dump(data, file_in_write_mode)
+                logging.info('Data Successfully Saved to {}'.format(
+                    json_file_location))
     elif output_format.lower() == "csv":
         if filename == "":
             filename = keyword
