@@ -1,26 +1,23 @@
 #!/usr/bin/env python3
-try:
-    from .driver_initialization import Initializer
-    from .driver_utils import Utilities
-    from inspect import currentframe
-    from .element_finder import Finder
-    from .driver_utils import Utilities
-    import re
-    import json
-    import csv
-    import os
-except Exception as ex:
-    frameinfo = currentframe()
-    print("Error on line no. {} : {}".format(frameinfo.f_lineno, ex))
 
-frameinfo = currentframe()
+from .driver_initialization import Initializer
+from .driver_utils import Utilities
+from .element_finder import Finder
+from .driver_utils import Utilities
+import re
+import json
+import csv
+import os
+import logging
+
+logging.getLogger().setLevel(logging.INFO)
 
 
 class Profile:
     """this class needs to be instantiated in orer to scrape post of some
     twitter profile"""
 
-    def __init__(self, twitter_username, browser, proxy, tweets_count, headless):
+    def __init__(self, twitter_username, browser, proxy, tweets_count, headless, browser_profile):
         self.twitter_username = twitter_username
         self.URL = "https://twitter.com/{}".format(twitter_username.lower())
         self.__driver = ""
@@ -30,11 +27,12 @@ class Profile:
         self.posts_data = {}
         self.retry = 10
         self.headless = headless
+        self.browser_profile = browser_profile
 
     def __start_driver(self):
         """changes the class member __driver value to driver on call"""
         self.__driver = Initializer(
-            self.browser, self.headless, self.proxy).init()
+            self.browser, self.headless, self.proxy, self.browser_profile).init()
 
     def __close_driver(self):
         self.__driver.close()
@@ -108,8 +106,8 @@ class Profile:
                     break
 
         except Exception as ex:
-            print("Error at method scrap on line no. {} : {}".format(
-                frameinfo.f_lineno, ex))
+            logging.exception(
+                "Error at method fetch_and_store_data : {}".format(ex))
 
     def scrap(self):
         try:
@@ -121,11 +119,11 @@ class Profile:
             self.__close_driver()
             data = dict(list(self.posts_data.items())
                         [0:int(self.tweets_count)])
-            return json.dumps(data)
+            return data
         except Exception as ex:
             self.__close_driver()
-            print("Error at method scrap on line no. {} : {}".format(
-                frameinfo.f_lineno, ex))
+            logging.exception(
+                "Error at method scrap : {} ".format(ex))
 
 
 def json_to_csv(filename, json_data, directory):
@@ -134,11 +132,15 @@ def json_to_csv(filename, json_data, directory):
     fieldnames = ['tweet_id', 'username', 'name', 'profile_picture', 'replies',
                   'retweets', 'likes', 'is_retweet', 'retweet_link', 'posted_time', 'content', 'hashtags', 'mentions',
                   'images', 'videos', 'tweet_url', 'link']
+    mode = 'w'
+    if os.path.exists("{}.csv".format(filename)):
+        mode = 'a'
     # open and start writing to CSV files
-    with open("{}.csv".format(filename), 'w', newline='', encoding="utf-8") as data_file:
+    with open("{}.csv".format(filename), mode, newline='', encoding="utf-8") as data_file:
         # instantiate DictWriter for writing CSV fi
         writer = csv.DictWriter(data_file, fieldnames=fieldnames)
-        writer.writeheader()  # write headers to CSV file
+        if mode == 'w':
+            writer.writeheader()  # write headers to CSV file
         # iterate over entire dictionary, write each posts as a row to CSV file
         for key in json_data:
             # parse post in a dictionary and write it as a single row
@@ -161,11 +163,12 @@ def json_to_csv(filename, json_data, directory):
                 "tweet_url": json_data[key]['tweet_url'],
                 "link": json_data[key]['link']
             }
-            writer.writerow(row)  # write row to CSV fi
+            writer.writerow(row)  # write row to CSV file
         data_file.close()  # after writing close the file
+    logging.info('Data Successfully Saved to {}.csv'.format(filename))
 
 
-def scrap_profile(twitter_username, browser="firefox", proxy=None, tweets_count=10, output_format="json", filename="", directory=os.getcwd(), headless=True):
+def scrap_profile(twitter_username, browser="firefox", proxy=None, tweets_count=10, output_format="json", filename="", directory=os.getcwd(), headless=True, browser_profile = None):
     """
     Returns tweets data in CSV or JSON.
 
@@ -184,15 +187,36 @@ def scrap_profile(twitter_username, browser="firefox", proxy=None, tweets_count=
 
     directory(string): If output_format parameter is set to CSV, then it is valid for directory parameter to be passed. If not passed then CSV file will be saved in current working directory.
 
-
+    browser_profile(string): Path of Browser Profile where cookies might be located to scrap data in authenticated way.
     """
     profile_bot = Profile(twitter_username, browser,
-                          proxy, tweets_count, headless)
+                          proxy, tweets_count, headless, browser_profile)
     data = profile_bot.scrap()
-    if output_format == "json":
-        return data
+    if output_format.lower() == "json":
+        if filename == '':
+          # if filename was not provided then print the JSON to console
+            return json.dumps(data)
+        elif filename != '':
+          # if filename was provided, save it to that file
+            mode = 'w'
+            json_file_location = os.path.join(directory, filename+".json")
+            if os.path.exists(json_file_location):
+                mode = 'r'
+            with open(json_file_location, mode, encoding='utf-8') as file:
+                if mode == 'r':
+                    try:
+                        file_content = file.read()
+                        content = json.loads(file_content)
+                    except json.decoder.JSONDecodeError:
+                        logging.warning('Invalid JSON Detected!')
+                        content = {}
+                    file.close()
+                    data.update(content)
+                    with open(json_file_location, 'w', encoding='utf-8') as file_in_write_mode:
+                        json.dump(data, file_in_write_mode)
+                logging.info(
+                    'Data Successfully Saved to {}'.format(json_file_location))
     elif output_format.lower() == "csv":
         if filename == "":
             filename = twitter_username
-        json_to_csv(filename=filename, json_data=json.loads(
-            data), directory=directory)
+        json_to_csv(filename=filename, json_data=data, directory=directory)
